
![logo](https://github.com/tweakoz/orkid/blob/develop/ork.data/dox/doxylogo.png "OrkidLogo")


### [BuildStatus](https://www.orkid-engine.dev:4431)

* Ubuntu 22.04 [![CISTATUS](https://www.orkid-engine.dev:4431/orkid-ix-ub2204/develop/status.svg)](https://www.orkid-engine.dev:4431)
* Ubuntu 20.04 [![CISTATUS](https://www.orkid-engine.dev:4431/orkid-ix-ub2004/develop/status.svg)](https://www.orkid-engine.dev:4431)

### Description

Orkid is a C++20 flexible media presentation engine. By media, we mean games, realtime 2d/3d graphics, and/or audio. Orkid itself is licensed with the permissive MIT license, that said Orkid does have dependencies on other libraries which will have different licenses and it is left up to the user to remain compliant with them. Orkid, being fairly modular can be run with less dependencies and reduced functionality to simplify license creep.

### History

Early Orkid was used for a a few games by Santa Cruz Games. It was used as both a game engine and tooling infrastructure.
 * Godzilla Unleashed for Nintendo DS (2007)
 * Tomb Raider Underworld for Nintendo DS (2008)
 * Igor The Game for the Wii and PC (2008)
 * Spongebob Gravjet Racing for Wii/Pc/XBox360 (2009)
 
 
Software Development Information
========

[How to build](ork.dox/building.md)

[How to run](ork.dox/running.md)

[GLSLFX shader format docs](ork.dox/glslfx.md)

[EngineLibraryTopology](ork.dox/engine_layout.md)
   * [Ork.Core.Reflection](ork.dox/reflection.md)
   * [Ork.Core.Datablocks](ork.dox/datablocks.md)
   * [Ork.Lev2.Graphics](ork.dox/lev2-graphics.md)
   * [Ork.ECS](ork.dox/ecs.md)

[Doxygen - code documentation](https://www.orkid-engine.dev:4430/doxygen_html/index.html)

Artist Information
========

[Blender pipeline notes](ork.dox/blender.md)

Example Content (most of it old, updates coming soon.)
========

<a href="https://media.githubusercontent.com/media/tweakoz/orkid/develop/ork.data/misc/screenshot_pbr.png"><img src="https://github.com/tweakoz/orkid/blob/develop/ork.data/misc/th_screenshot_pbr.png" title="Github Logo"></a>
<a href="https://media.githubusercontent.com/media/tweakoz/orkid/develop/ork.data/misc/shadowedptexspotlight.png"><img src="https://github.com/tweakoz/orkid/blob/develop/ork.data/misc/th_shadowedptexspotlight.png" title="Github Logo"></a>

![Particles](http://tweakoz.com/resources/images/th_sshot_psys.jpg)

![ProceduralTextures](http://tweakoz.com/resources/images/th_sshot_proctex.jpg)

![TerrainGen](http://tweakoz.com/resources/images/th_terrain03.jpg)

Other (video) examples of content:

[PBR ShaderBalls](https://www.youtube.com/watch?v=LtlVotV_9vg_)

[SceneGraph-Picking](https://youtu.be/d39JF4ApsVw)

[Deferred-PBR-SpotLightProjectors-1](https://www.youtube.com/watch?v=AwhDNZPhcBk)

[Deferred-PBR-PointLightProjectors-1](https://www.youtube.com/watch?v=ffEbkF9l4yw)

[Deferred-PBR-PointLightProjectors-2](https://www.youtube.com/watch?v=Xem37Nfp-d8)

[MoonDiver](https://youtu.be/2zNd4k_6I6s)

[Compositor](https://www.youtube.com/watch?v=zLBhF8WCDgQ)

[NodeCompositor](https://www.youtube.com/watch?v=AGMazbsbJYE)

[Particles-Vortex&TurbulenceNodes](https://youtu.be/Qr8QK6ns0Tk)

[Paritcles-SphereColliderNode](https://www.youtube.com/watch?v=yb9a6k4VeaU)

[Particles-MultiSystem](https://www.youtube.com/watch?v=o7uJFNQc3Go)

[Particles-ChainOfSystems](https://youtu.be/sQTiz0Ooo6I)

[ParticlesAndCompositor](https://www.youtube.com/watch?v=qmULG3ZOoS0)

[ProceduralTexture](https://www.youtube.com/watch?v=FdAfxQjR3AQ)

[Prodigy2-GameDemo](http://tweakoz.com/resources/videos/p2d.mp4)

[OrkidVR-POC](https://www.youtube.com/watch?v=6tOPVw8T_sU)

[Singularity-NewAudioSynth](https://www.youtube.com/watch?v=irBaba13quQ)

[Singularity-ModulatorHUD](https://www.youtube.com/watch?v=1PEXp9-6eRA)

